@@ -24,6 +24,7 @@
 #include "gusb-device-event-private.h"
 #include "gusb-device-private.h"
 #include "gusb-interface-private.h"
+#include "gusb-json-common.h"
 #include "gusb-util.h"
 
 /**
@@ -242,7 +243,6 @@ _g_usb_device_load(GUsbDevice *self, JsonObject *json_object, GError **error)
 	g_return_val_if_fail(json_object != NULL, FALSE);
 	g_return_val_if_fail(error == NULL || *error == NULL, FALSE);
 
-#if JSON_CHECK_VERSION(1, 6, 0)
 	/* optional properties */
 	tmp = json_object_get_string_member_with_default(json_object, "PlatformId", NULL);
 	if (tmp != NULL) {
@@ -281,13 +281,6 @@ _g_usb_device_load(GUsbDevice *self, JsonObject *json_object, GError **error)
 	priv->desc.iProduct = json_object_get_int_member_with_default(json_object, "Product", 0x0);
 	priv->desc.iSerialNumber =
 	    json_object_get_int_member_with_default(json_object, "SerialNumber", 0x0);
-#else
-	g_set_error_literal(error,
-			    G_IO_ERROR,
-			    G_IO_ERROR_NOT_SUPPORTED,
-			    "json-glib version too old");
-	return FALSE;
-#endif
 
 	/* array of BOS descriptors */
 	if (json_object_has_member(json_object, "UsbBosDescriptors")) {
@@ -894,6 +887,7 @@ g_usb_device_load_event(GUsbDevice *self, const gchar *id)
 		if (g_strcmp0(g_usb_device_event_get_id(event), id) == 0) {
 			if (_g_usb_context_has_flag(priv->context, G_USB_CONTEXT_FLAGS_DEBUG))
 				g_debug("found out-of-order %s at position %u", id, i);
+			priv->event_idx = i + 1;
 			return event;
 		}
 	}
@@ -3002,7 +2996,7 @@ g_usb_device_get_configuration_index(GUsbDevice *self)
 		bytes = g_usb_device_event_get_bytes(event);
 		if (bytes == NULL && g_bytes_get_size(bytes) != 1)
 			return 0x0;
-		return ((const guint8 *) g_bytes_get_data(bytes, NULL))[0];
+		return ((const guint8 *)g_bytes_get_data(bytes, NULL))[0];
 	}
 
 	rc = libusb_get_active_config_descriptor(priv->device, &config);
